@@ -5,7 +5,7 @@ import shutil
 import socketserver
 import webbrowser
 from importlib.resources import path
-from typing import Any
+from typing import Any, Union
 
 import typer
 from dotenv import load_dotenv
@@ -26,8 +26,12 @@ logger = logging.getLogger("NotionScripting")
 
 
 @app.command()
-def download(database_id: str = typer.Argument("", envvar="DATABASE_ID"), section_name: str = "Written"):
-    notion_processor = NotionProcessor(notion_client)
+def download(
+    database_id: str = typer.Argument("", envvar="DATABASE_ID"),
+    section_name: str = "Written",
+    content_root: Union[str, None] = None,
+):
+    notion_processor = NotionProcessor(notion_client, content_root=content_root)
     notion_processor.create_scripts(database_id, section_name)
 
 
