@@ -1,10 +1,21 @@
-from typing import Dict, List
+from typing import Dict, List, Tuple
 
 import requests
 
 
-def query_db(status: str) -> Dict:
-    return {"filter": {"or": [{"property": "Status", "select": {"equals": status}}]}}
+def build_filter_query(properties: Tuple[str, str, str]) -> Dict:
+    """
+    Builds a query to filter for pages with the properties specified as triplets
+
+    :param properties: A list of triplets containing (property, condition, value)
+    :return:
+    """
+
+    or_conditions = [
+        {"property": property_name, "select": {condition: value}} for property_name, condition, value in properties
+    ]
+
+    return {"filter": {"or": or_conditions}}
 
 
 class NotionClient:
@@ -22,7 +33,7 @@ class NotionClient:
         return database
 
     def get_pages(self, page_status: str, database_id: str) -> List[Dict]:
-        query = query_db(page_status)
+        query = build_filter_query([("Status", "equals", page_status)])
         database = requests.post(
             f"https://api.notion.com/v1/databases/{database_id}/query",
             json=query,
